@@ -1,13 +1,13 @@
 import random
 from typing import Optional, IO
 
-from domain.engine.engine_section import EngineSection
-from domain.frame.frame_element import FrameElement
-from domain.json_serializable.custom_json_serializable import JSONSerializable
+from xlsx_lib.domain.engine.engine_section import EngineSection
+from xlsx_lib.domain.frame.frame_element import FrameElement
+from xlsx_lib.domain.json_serializable.custom_json_serializable import JSONSerializable
 
-from domain.generic_replacements.replacement import Replacement
-from domain.tightening_torques.component import Component
-from domain.electronic.electronic_element import ElectronicElement
+from xlsx_lib.domain.generic_replacements.replacement import Replacement
+from xlsx_lib.domain.tightening_torques.component import Component
+from xlsx_lib.domain.electronic.electronic_element import ElectronicElement
 
 
 class MotorcycleModel(JSONSerializable):
